@@ -44,6 +44,7 @@ default_keys = (
     ("clock_on", bool, []),
     ("contact_email_on_error", six.text_type, []),
     ("chrome-path", six.text_type, []),
+    ("dallinger_develop_directory", six.text_type, []),
     ("dallinger_email_address", six.text_type, []),
     ("dashboard_password", six.text_type, [], True),
     ("dashboard_user", six.text_type, [], True),
@@ -84,6 +85,7 @@ default_keys = (
     ("prolific_maximum_allowed_minutes", int, []),
     ("prolific_recruitment_config", six.text_type, [], False, [is_valid_json]),
     ("prolific_reward_cents", int, []),
+    ("protected_routes", six.text_type, [], False, [is_valid_json]),
     ("recruiter", six.text_type, []),
     ("recruiters", six.text_type, []),
     ("redis_size", six.text_type, []),
@@ -102,6 +104,7 @@ default_keys = (
     ("worker_multiplier", float, []),
     ("docker_image_base_name", six.text_type, [], ""),
     ("docker_image_name", six.text_type, [], ""),
+    ("docker_volumes", six.text_type, [], ""),
 )
 
 
@@ -191,7 +194,10 @@ class Configuration(object):
             except KeyError:
                 continue
         if default is marker:
-            raise KeyError(key)
+            raise KeyError(
+                f"The following config parameter was not set: {key}. Consider setting it in "
+                "config.txt or in ~/.dallingerconfig."
+            )
         return default
 
     def __getitem__(self, key):
@@ -267,7 +273,8 @@ class Configuration(object):
     def load_defaults(self):
         """Load default configuration values"""
         # Apply extra parameters before loading the configs
-        self.register_extra_parameters()
+        if self.experiment_available():
+            self.register_extra_parameters()
 
         global_config_name = ".dallingerconfig"
         global_config = os.path.expanduser(os.path.join("~/", global_config_name))
@@ -281,6 +288,9 @@ class Configuration(object):
         for config_file in [global_defaults_file, local_defaults_file, global_config]:
             self.load_from_file(config_file)
 
+    def experiment_available(self):
+        return Path("experiment.py").exists()
+
     def load(self):
         self.load_defaults()
 
@@ -291,9 +301,6 @@ class Configuration(object):
         self.load_from_environment()
         self.ready = True
 
-        if self.get("docker_image_base_name", None) is None:
-            self.set("docker_image_base_name", Path(os.getcwd()).name)
-
     def register_extra_parameters(self):
         initialize_experiment_package(os.getcwd())
         extra_parameters = None
@@ -302,10 +309,7 @@ class Configuration(object):
         # This will run any experiment specific parameter registrations
         from dallinger.experiment import load
 
-        try:
-            exp_klass = load()
-        except ImportError:
-            exp_klass = None
+        exp_klass = load()
         exp_params = getattr(exp_klass, "extra_parameters", None)
         if exp_params is not None and not self._experiment_params_loaded:
             exp_params()
