@@ -391,7 +391,11 @@ def check_local_db_connection(log):
 def check_experiment_dependencies(requirement_file):
     """Verify that the dependencies defined in a requirements file are
     in fact installed.
+    If the environment variable SKIP_DEPENDENCY_CHECK is set, no check
+    will be performed.
     """
+    if os.environ.get("SKIP_DEPENDENCY_CHECK"):
+        return
     try:
         with open(requirement_file, "r") as f:
             dependencies = [r for r in f.readlines() if r[:3] != "-e "]
@@ -400,6 +404,32 @@ def check_experiment_dependencies(requirement_file):
     pkg_resources.require(dependencies)
 
 
+def develop_target_path(config):
+    """Extract the target `dallinger develop` working directory from
+    configuration, and return it as a Path.
+    """
+    develop_path_string = config.get("dallinger_develop_directory", None)
+    try:
+        develop_path = Path(develop_path_string).expanduser()
+    except TypeError:
+        raise ValueError(
+            'The Dallinger configuration value "dallinger_develop_directory" '
+            'must be a file path, like "~/dallinger_develop".\n'
+            'Your value is "{}" which cannot be translated '
+            "to a file path.".format(develop_path_string)
+        )
+    if not develop_path.name.isidentifier():
+        raise ValueError(
+            'The directory in the Dallinger configuration value "dallinger_develop_directory" '
+            "must be a valid python identifier: only letters, numbers and underscores are allowed.\n"
+            'The directory name "{}" is not a valid identifier.'.format(
+                develop_path.name
+            )
+        )
+
+    return develop_path
+
+
 def bootstrap_development_session(exp_config, experiment_path, log):
     check_local_db_connection(log)
     check_experiment_dependencies(Path(experiment_path) / "requirements.txt")
@@ -424,22 +454,26 @@ def bootstrap_development_session(exp_config, experiment_path, log):
     if not config.get("dashboard_password", None):
         config.set("dashboard_password", fake.password(length=20, special_chars=False))
 
-    develop_source_path = Path(dallinger_package_path()) / "dev_server"
-    dst = Path(experiment_path) / "develop"
+    source_path = Path(dallinger_package_path()) / "dev_server"
+    destination_path = develop_target_path(config)
+
     log("Wiping develop directory and re-writing it...")
-    ensure_directory(dst)
-    expunge_directory(dst)
+    ensure_directory(destination_path)
+    expunge_directory(destination_path)
     collate_experiment_files(
-        config, experiment_path=experiment_path, destination=dst, copy_func=symlink_file
+        config,
+        experiment_path=experiment_path,
+        destination=destination_path,
+        copy_func=symlink_file,
     )
 
-    copy_file(develop_source_path / "app.py", dst / "app.py")
-    copy_file(develop_source_path / "run.sh", dst / "run.sh")
-    (dst / "run.sh").chmod(0o744)  # Make run script executable
+    copy_file(source_path / "app.py", destination_path / "app.py")
+    copy_file(source_path / "run.sh", destination_path / "run.sh")
+    (destination_path / "run.sh").chmod(0o744)  # Make run script executable
 
-    config.write(directory=dst)
+    config.write(directory=destination_path)
 
-    return (experiment_uid, dst)
+    return (experiment_uid, destination_path)
 
 
 def setup_experiment(
@@ -511,7 +545,12 @@ def ensure_constraints_file_presence(directory: str):
 
     If the `requirements.txt` does not exist one is created with
     `dallinger` as its only dependency.
+
+    If the environment variable SKIP_DEPENDENCY_CHECK is set, no action
+    will be performed.
     """
+    if os.environ.get("SKIP_DEPENDENCY_CHECK"):
+        return
     constraints_path = Path(directory) / "constraints.txt"
     requirements_path = Path(directory) / "requirements.txt"
     if not requirements_path.exists():
@@ -606,13 +645,15 @@ def assemble_experiment_temp_dir(log, config, for_remote=False):
         file.write(exp_id)
 
     # Write out a runtime.txt file based on configuration
-    pyversion = config.get("heroku_python_version")
-    with open(os.path.join(dst, "runtime.txt"), "w") as file:
-        file.write("python-{}".format(pyversion))
+    pyversion = config.get("heroku_python_version", None)
+    if pyversion:
+        with open(os.path.join(dst, "runtime.txt"), "w") as file:
+            file.write("python-{}".format(pyversion))
 
     requirements_path = Path(dst) / "requirements.txt"
     # Overwrite the requirements.txt file with the contents of the constraints.txt file
-    (Path(dst) / "constraints.txt").replace(requirements_path)
+    if not os.environ.get("SKIP_DEPENDENCY_CHECK"):
+        (Path(dst) / "constraints.txt").replace(requirements_path)
     if for_remote:
         dallinger_path = get_editable_dallinger_path()
         if dallinger_path and not os.environ.get("DALLINGER_NO_EGG_BUILD"):
